aboutsummaryrefslogtreecommitdiff
path: root/html/install.js
diff options
context:
space:
mode:
Diffstat (limited to 'html/install.js')
-rw-r--r--html/install.js42
1 files changed, 17 insertions, 25 deletions
diff --git a/html/install.js b/html/install.js
index 95388a3..c502719 100644
--- a/html/install.js
+++ b/html/install.js
@@ -45,10 +45,11 @@
#IMPORT html/dialog.js
#IMPORT html/item_preview.js AS ip
#FROM common/browser.js IMPORT browser
#FROM html/DOM_helpers.js IMPORT clone_template, Showable
#FROM common/entities.js IMPORT item_id_string, version_string, get_files
#FROM common/misc.js IMPORT sha256_async AS compute_sha256
const coll = new Intl.Collator();
@@ -113,19 +114,6 @@ async function init_work() {
new Promise((...cbs) => [work.resolve_cb, work.reject_cb] = cbs)];
}
-function _make_url_reg(item_type) {
- return new RegExp(
- `^https://hydrilla\\.koszko\\.org/schemas/api_${item_type}_description-1\\.([1-9][0-9]*\\.)*schema\\.json$`
- );
-}
-
-const _regexes = {};
-
-function item_schema_url_regex(item_type) {
- _regexes[item_type] = _regexes[item_type] || _make_url_reg(item_type);
- return _regexes[item_type];
-}
-
function InstallView(tab_id, on_view_show, on_view_hide) {
Showable.call(this, on_view_show, on_view_hide);
@@ -204,18 +192,22 @@ function InstallView(tab_id, on_view_show, on_view_hide) {
}
const captype = item_type[0].toUpperCase() + item_type.substring(1);
- const reg = item_schema_url_regex(item_type);
- if (!response.json["$schema"]) {
+ const $id =
+ `https://hydrilla.koszko.org/schemas/api_${item_type}_description-1.0.1.schema.json`;
+ const schema = haketilo_schemas[$id];
+ const result = haketilo_validator.validate(response.json, schema);
+ if (result.errors.length > 0) {
+ const reg = new RegExp(schema.allOf[2].properties.$schema.pattern);
+ if (response.json.$schema && !reg.test(response.json.$schema)) {
+ const msg = `${captype} ${item_id_string(id, ver)} was served using unsupported Hydrilla API version. You might need to update Haketilo.`;
+ return work.err(result.errors, msg);
+ }
+
const msg = `${captype} ${item_id_string(id, ver)} was served using a nonconforming response format.`;
- return work.err(null, msg);
- } else if (!reg.test(response.json["$schema"])) {
- const msg = `${captype} ${item_id_string(id, ver)} was served using unsupported Hydrilla API version. You might need to update Haketilo.`;
- return work.err(null, msg);
+ return work.err(result.errors, msg);
}
- /* TODO: JSON schema validation should be added here. */
-
const scripts = item_type === "resource" && response.json.scripts;
const files = response.json.source_copyright.concat(scripts || []);
@@ -45,10 +45,11 @@
#IMPORT html/dialog.js
#IMPORT html/item_preview.js AS ip
-#FROM common/browser.js IMPORT browser
-#FROM html/DOM_helpers.js IMPORT clone_template, Showable
-#FROM common/entities.js IMPORT item_id_string, version_string, get_files
-#FROM common/misc.js IMPORT sha256_async AS compute_sha256
+#FROM common/browser.js IMPORT browser
+#FROM html/DOM_helpers.js IMPORT clone_template, Showable
+#FROM common/entities.js IMPORT item_id_string, version_string, get_files
+#FROM common/misc.js IMPORT sha256_async AS compute_sha256
+#FROM common/jsonschema.js IMPORT haketilo_validator, haketilo_schemas
const coll = new Intl.Collator();